@@ -9,7 +9,7 @@ use strict;
 use warnings;
 
 BEGIN {
-   our $VERSION = '0.55';
+   our $VERSION = '0.56';
 }
 
 use Carp;
@@ -143,7 +143,7 @@ sub new
 
       require Tickit::Term;
 
-      $term = Tickit::Term->find_for_term(
+      $term = Tickit::Term->new(
          writer        => $writer,
          input_handle  => $in,
          output_handle => $out,
