@@ -8,7 +8,7 @@ package Tickit::Pen;
 use strict;
 use warnings;
 
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 use Carp;
 
@@ -38,11 +38,7 @@ hash.
 A mutable pen is an instance of C<Tickit::Pen::Mutable>. Its attributes may be
 set by the constructor, and can be changed at any time. As well as supporting
 the same query methods as immutable pens, more methods are provided to change
-or remove them. Mutable pens also currently support the concept of observers;
-other objects that will be informed when pen attributes are changed. However,
-these were only added to support an earlier version of what eventually became
-L<Tickit::Style>, and are no longer required. They will be removed in a later
-version.
+or remove them.
 
 While mutable pens may initially seem more useful, they can complicate logic
 due to their shared referential nature. If the same mutable pen is shared
@@ -316,35 +312,15 @@ sub default_from
    return $self;
 }
 
-=head2 add_on_changed
+sub add_on_changed
+{
+   croak "\$pen->add_on_changed has been removed";
+}
 
-   $pen->add_on_changed( $observer, $id )
-
-Add an observer to the list of objects which will be informed when the pen
-attributes change. The observer will be informed by invoking a method
-C<on_pen_changed>, passing in the pen reference and the opaque ID value given
-to this method.
-
- $observer->on_pen_changed( $pen, $id )
-
-The observer object is stored weakly, so it is safe to add the
-C<Tickit::Widget> object that is using the pen as an observer. The ID value is
-not weakened.
-
-The use of pen observers is now deprecated, and will be removed in a later
-version. This was a short-lived feature intended for adding mutable styles to
-widgets, which is now much better served by the L<Tickit::Style> system
-instead.
-
-=cut
-
-=head2 remove_on_changed
-
-   $pen->remove_on_changed( $observer )
-
-Remove an observer previously added by C<add_on_changed>.
-
-=cut
+sub remove_on_changed
+{
+   croak "\$pen->remove_on_changed has been removed";
+}
 
 sub sprintf
 {
@@ -368,14 +344,14 @@ use overload '==' => sub { refaddr($_[0]) == refaddr($_[1]) };
 package Tickit::Pen::Immutable;
 use base qw( Tickit::Pen );
 use constant mutable => 0;
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 sub as_immutable { return $_[0] }
 
 package Tickit::Pen::Mutable;
 use base qw( Tickit::Pen );
 use constant mutable => 1;
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 # Adds further methods in XS
 
