@@ -8,7 +8,7 @@ package Tickit::Term;
 use strict;
 use warnings;
 
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 use Carp;
 
@@ -52,32 +52,6 @@ distribution.
 
 =cut
 
-=head2 find_for_term
-
-   $term = Tickit::Term->find_for_term( %params )
-
-Attempts to load and construct a subclass determined by the current terminal
-type (as given by C<$ENV{TERM}>). If this fails, returns a normal
-C<Tickit::Term> instead.
-
-=cut
-
-sub find_for_term
-{
-   my $class = shift;
-
-   if( defined( my $term = $ENV{TERM} ) ) {
-      my $subclass = "${class}::$term";
-      ( my $file = "$subclass.pm" ) =~ s{::}{/}g;
-
-      my $self;
-      eval { require $file and $self = $subclass->new( @_ ) } and
-         return $self;
-   }
-
-   return $class->new( @_ );
-}
-
 =head2 new
 
    $term = Tickit::Term->new( %params )
@@ -151,6 +125,12 @@ sub new
 
 Returns the input handle set by the C<input_handle> constructor arg.
 
+Note that because L<Tickit::Term> merely wraps an object provided by the
+lower-level F<libtickit> C library, it is no longer guaranteed that this
+method will return the same perl-level object that was given to the
+constructor. The object may be newly-constructed to represent a new perl-level
+readable filehandle on the same file number.
+
 =cut
 
 =head2 get_output_handle
@@ -159,6 +139,12 @@ Returns the input handle set by the C<input_handle> constructor arg.
 
 Returns the output handle set by the C<output_handle> constructor arg.
 
+Note that because L<Tickit::Term> merely wraps an object provided by the
+lower-level F<libtickit> C library, it is no longer guaranteed that this
+method will return the same perl-level object that was given to the
+constructor. The object may be newly-constructed to represent a new perl-level
+writable filehandle on the same file number.
+
 =cut
 
 =head2 set_output_buffer
@@ -260,6 +246,8 @@ sub set_on_resize
    my $self = shift;
    my ( $code ) = @_;
 
+   carp "\$term->set_on_resize is deprecated; use ->bind_event";
+
    $self->unbind_event_id( delete $self->_event_ids->{resize} ) if exists $self->_event_ids->{resize};
    $self->_event_ids->{resize} = $self->bind_event( resize => sub {
       my ( undef, $ev, $args ) = @_;
@@ -272,6 +260,8 @@ sub set_on_key
    my $self = shift;
    my ( $code ) = @_;
 
+   carp "\$term->set_on_key is deprecated; use ->bind_event";
+
    $self->unbind_event_id( delete $self->_event_ids->{key} ) if exists $self->_event_ids->{key};
    $self->_event_ids->{key} = $self->bind_event( key => sub {
       my ( undef, $ev, $args ) = @_;
@@ -284,6 +274,8 @@ sub set_on_mouse
    my $self = shift;
    my ( $code ) = @_;
 
+   carp "\$term->set_on_mouse is deprecated; use ->bind_event";
+
    $self->unbind_event_id( delete $self->_event_ids->{mouse} ) if exists $self->_event_ids->{mouse};
    $self->_event_ids->{mouse} = $self->bind_event( mouse => sub {
       my ( undef, $ev, $args ) = @_;
