@@ -305,8 +305,12 @@ void tickit_window_destroy(TickitWindow *win)
   if(win->pen)
     tickit_pen_unref(win->pen);
 
-  for(TickitWindow *child = win->first_child; child; child = child->next)
+  for(TickitWindow *child = win->first_child; child; /**/) {
+    TickitWindow *next = child->next;
+
     tickit_window_destroy(child);
+    child = next;
+  }
 
   _purge_hierarchy_changes(win);
 
@@ -563,7 +567,7 @@ static void _request_later_processing(TickitRootWindow *root)
 
 static bool _cell_visible(TickitWindow *win, int line, int col)
 {
-  TickitWindow *prev;
+  TickitWindow *prev = NULL;
   while(win) {
     if(line < 0 || line >= win->rect.lines ||
        col  < 0 || col  >= win->rect.cols)
